@@ -4,9 +4,11 @@ use strict;
 use vars qw($VERSION);
 
 use Alzabo::Create;
+use Alzabo::Exceptions ( abbr => 'params_exception' );
 
 use Params::Validate qw( :all );
-Params::Validate::validation_options( on_fail => sub { Alzabo::Exception::Params->throw( error => join '', @_ ) } );
+Params::Validate::validation_options
+    ( on_fail => sub { params_exception join '', @_ } );
 
 use base qw(Alzabo::ColumnDefinition);
 
@@ -79,14 +81,8 @@ sub alter
 	$self->{type} = $old_type;
 	$self->{length} = $old_length;
 	$self->{precision} = $old_precision;
-	if ( UNIVERSAL::can( $@, 'rethrow' ) )
-	{
-	    $@->rethrow;
-	}
-	else
-	{
-	    Alzabo::Exception->throw( error => $@ );
-	}
+
+        rethrow_exception($@);
     }
 }
 
@@ -109,14 +105,8 @@ sub set_type
     if ($@)
     {
 	$self->{type} = $old_type;
-	if ( UNIVERSAL::can( $@, 'rethrow' ) )
-	{
-	    $@->rethrow;
-	}
-	else
-	{
-	    Alzabo::Exception->throw( error => $@ );
-	}
+
+        rethrow_exception($@);
     }
 }
 
@@ -142,17 +132,13 @@ sub set_length
     {
 	$self->{length} = $old_length;
 	$self->{precision} = $old_precision;
-	if ( UNIVERSAL::can( $@, 'rethrow' ) )
-	{
-	    $@->rethrow;
-	}
-	else
-	{
-	    Alzabo::Exception->throw( error => $@ );
-	}
+
+        rethrow_exception($@);
     }
 }
 
+1;
+
 __END__
 
 =head1 NAME
@@ -184,7 +170,7 @@ C<Alzabo::ColumnDefinition>
 
 =head2 new
 
-=head3 Parameters
+This method takes the following parameters:
 
 =over 4
 
@@ -194,27 +180,12 @@ C<Alzabo::ColumnDefinition>
 
 =back
 
-=head3 Returns
-
-A new C<Alzabo::Create::ColumnDefinition> object.
+It returns a new C<Alzabo::Create::ColumnDefinition> object.
 
 =head2 alter
 
-This method allows you to change a column's type, length, and
-precision as a single operation and should be instead of calling
-C<set_type> followed by C<set_length>.
-
-=head3 Parameters
-
-=over 4
-
-=item * type => $type
-
-=item * length => $length (optional)
-
-=item * precision => $precision (optional)
-
-=back
+See the L<C<< Alzabo::Column->alter() >>|Alzabo::Column/alter> method
+for details.
 
 =for pod_merge type
 
@@ -222,13 +193,16 @@ C<set_type> followed by C<set_length>.
 
 Sets the object's type.
 
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>,
+L<C<Alzabo::Exception::RDBMSRules>|Alzabo::Exceptions>
+
 =for pod_merge length
 
 =for pod_merge precision
 
 =head2 set_length
 
-=head3 Parameters
+This method takes the following parameters:
 
 =over 4
 
@@ -242,6 +216,9 @@ Sets the column's length and precision.  The precision parameter is
 optional (though some column types may require it if the length is
 set).
 
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>,
+L<C<Alzabo::Exception::RDBMSRules>|Alzabo::Exceptions>
+
 =for pod_merge owner
 
 =cut
