@@ -4,9 +4,11 @@ use strict;
 use vars qw($VERSION);
 
 use Alzabo::Create;
+use Alzabo::Exceptions ( abbr => 'params_exception' );
 
 use Params::Validate qw( :all );
-Params::Validate::validation_options( on_fail => sub { Alzabo::Exception::Params->throw( error => join '', @_ ) } );
+Params::Validate::validation_options
+    ( on_fail => sub { params_exception join '', @_ } );
 
 use base qw(Alzabo::ForeignKey);
 
@@ -52,8 +54,9 @@ sub set_columns_from
 
     if ( exists $self->{columns_to} )
     {
-	Alzabo::Exception::Params->throw( error => "The number of columns in each part of the relationship must be the same" )
-	    unless @{ $self->{columns_to} } == @$c;
+	params_exception
+            "The number of columns in each part of the relationship must be the same"
+                unless @{ $self->{columns_to} } == @$c;
     }
 
     $self->{columns_from} = $c;
@@ -68,8 +71,9 @@ sub set_columns_to
 
     if ( exists $self->{columns_from} )
     {
-	Alzabo::Exception::Params->throw( error => "The number of columns in each part of the relationship must be the same" )
-	    unless @{ $self->{columns_from} } == @$c;
+	params_exception
+            "The number of columns in each part of the relationship must be the same"
+                unless @{ $self->{columns_from} } == @$c;
     }
 
     $self->{columns_to} = $c;
@@ -81,16 +85,16 @@ sub set_cardinality
 
     my @card = @_;
 
-    Alzabo::Exception::Params->throw( error => "Incorrect number of elements for cardinality" )
+    params_exception "Incorrect number of elements for cardinality"
 	unless scalar @card == 2;
 
     foreach my $c ( @card )
     {
-	Alzabo::Exception::Params->throw( error => "Invalid cardinality piece: $c" )
+	params_exception "Invalid cardinality piece: $c"
 	    unless $c =~ /^[1n]$/i;
     }
 
-    Alzabo::Exception::Params->throw( error => "Invalid cardinality: $card[0]..$card[1]" )
+    params_exception "Invalid cardinality: $card[0]..$card[1]"
 	if $card[0] eq 'n' && $card[1] eq 'n';
 
     $self->{cardinality} = \@card;
@@ -134,7 +138,7 @@ C<Alzabo::ForeignKey>
 
 =head2 new
 
-Parameters:
+The constructor takes the following parameters:
 
 =over 4
 
@@ -158,10 +162,10 @@ An optional comment.
 
 =back
 
-=head3 Returns
+It returns a new
+L<C<Alzabo::Create::ForeignKey>|Alzabo::Create::ForeignKey> object.
 
-A new L<C<Alzabo::Create::ForeignKey>|Alzabo::Create::ForeignKey>
-object.
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
 
 =for pod_merge table_from
 
@@ -175,13 +179,17 @@ object.
 
 =head2 set_columns_from (C<Alzabo::Create::Column> object(s))
 
-Set the column(s) that the relation is from.  This can be either a
-single a column object or a reference to an array of column objects.
+Sets the column(s) that the relation is from.  This can be either a
+single column object or a reference to an array of column objects.
+
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
 
 =head2 set_columns_to (C<Alzabo::Create::Column> object(s))
 
-Set the column(s) that the relation is to.  This can be either a
-single a column object or a reference to an array of column objects.
+Sets the column(s) that the relation is to.  This can be either a
+single column object or a reference to an array of column objects.
+
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
 
 =for pod_merge cardinality
 
@@ -197,25 +205,31 @@ single a column object or a reference to an array of column objects.
 
 =head2 set_cardinality (\@cardinality) see above for details
 
-Sets the cardinality value of the relation.
+Sets the cardinality of the foreign key.
+
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
 
 =head2 set_from_is_dependent ($boolean)
 
-Indicates whether or not the first table in the relationship is
+Indicates whether or not the first table in the foreign key is
 dependent on the other (i.e. whether the 'from' table is dependent on
 the 'to' table).
 
 =head2 set_to_is_dependent ($boolean)
 
-Indicates whether or not the second table in the relationship is
+Indicates whether or not the second table in the foreign key is
 dependent on the other (i.e. whether the 'to' table is dependent on
 the 'from' table).
 
+=for pod_merge id
+
+=for pod_merge is_same_relationship_as ($fk)
+
 =for pod_merge comment
 
 =head2 set_comment ($comment)
 
-Set the comment for the foreign key object.
+Sets the comment for the foreign key object.
 
 =head1 AUTHOR
 
