@@ -4,9 +4,11 @@ use strict;
 use vars qw($VERSION);
 
 use Alzabo::Create;
+use Alzabo::Exceptions ( abbr => 'params_exception' );
 
 use Params::Validate qw( :all );
-Params::Validate::validation_options( on_fail => sub { Alzabo::Exception::Params->throw( error => join '', @_ ) } );
+Params::Validate::validation_options
+    ( on_fail => sub { params_exception join '', @_ } );
 
 use base qw(Alzabo::Index);
 
@@ -21,8 +23,9 @@ sub new
 
     validate( @_, { table    => { isa => 'Alzabo::Create::Table' },
 		    columns  => { type => ARRAYREF },
-		    unique   => { optional => 1 },
-		    fulltext => { optional => 1 },
+		    unique   => { type => BOOLEAN, default => 0 },
+		    fulltext => { type => BOOLEAN, default => 0 },
+		    function => { type => UNDEF | SCALAR,  default => undef },
 		  } );
     my %p = @_;
 
@@ -31,6 +34,7 @@ sub new
     $self->{table} = $p{table};
     $self->{unique} = $p{unique} || 0;
     $self->{fulltext} = $p{fulltext} || 0;
+    $self->{function} = $p{function};
 
     $self->{columns} = Tie::IxHash->new;
 
@@ -56,7 +60,7 @@ sub add_column
 
     my $new_name = $p{column}->name;
 
-    Alzabo::Exception::Params->throw( "Column $new_name already exists in index." )
+    params_exception "Column $new_name already exists in index."
 	if $self->{columns}->EXISTS($new_name);
 
     $self->{columns}->STORE( $new_name, \%p );
@@ -66,14 +70,8 @@ sub add_column
     if ($@)
     {
 	$self->{columns}->DELETE($new_name);
-	if ( UNIVERSAL::can( $@, 'rethrow' ) )
-	{
-	    $@->rethrow;
-	}
-	else
-	{
-	    Alzabo::Exception->throw( error => $@ );
-	}
+
+        rethrow_exception($@);
     }
 }
 
@@ -84,7 +82,7 @@ sub delete_column
     validate_pos( @_, { isa => 'Alzabo::Create::Column' } );
     my $c = shift;
 
-    Alzabo::Exception::Params->throw( error => "Column " . $c->name . " is not part of index." )
+    params_exception "Column " . $c->name . " is not part of index."
 	unless $self->{columns}->EXISTS( $c->name );
 
     $self->{columns}->DELETE( $c->name );
@@ -98,7 +96,7 @@ sub set_prefix
 		    prefix => { type => SCALAR } } );
     my %p = @_;
 
-    Alzabo::Exception::Params->throw( error => "Column " . $p{column}->name . " is not part of index." )
+    params_exception "Column " . $p{column}->name . " is not part of index."
 	unless $self->{columns}->EXISTS( $p{column}->name );
 
     my $col = $self->{columns}->FETCH( $p{column}->name );
@@ -118,14 +116,7 @@ sub set_prefix
 	    delete $col->{prefix};
 	}
 
-	if ( UNIVERSAL::can( $@, 'rethrow' ) )
-	{
-	    $@->rethrow;
-	}
-	else
-	{
-	    Alzabo::Exception->throw( error => $@ );
-	}
+        rethrow_exception($@);
     }
 }
 
@@ -142,7 +133,19 @@ sub set_fulltext
     my $self = shift;
 
     validate_pos( @_, 1 );
+
+    my $old_val = $self->{fulltext};
+
     $self->{fulltext} = shift;
+
+    eval { $self->table->schema->rules->validate_index($self); };
+
+    if ($@)
+    {
+        $self->{fulltext} = $old_val;
+
+        rethrow_exception($@);
+    }
 }
 
 sub register_column_name_change
@@ -185,7 +188,7 @@ C<Alzabo::Index>
 
 =head2 new
 
-=head3 Parameters
+The constructor takes the following parameters:
 
 =over 4
 
@@ -217,9 +220,10 @@ Indicates whether or not this is a fulltext index.
 
 =back
 
-=head3 Returns
+Returns a new C<Alzabo::Create::Index> object.
 
-A new C<Alzabo::Create::Index> object.
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>,
+L<C<Alzabo::Exception::RDBMSRules>|Alzabo::Exceptions>
 
 =for pod_merge table
 
@@ -227,9 +231,9 @@ A new C<Alzabo::Create::Index> object.
 
 =head2 add_column
 
-Add a column to the index.
+Adds a column to the index.
 
-=head3 Parameters
+This method takes the following parameters:
 
 =over 4
 
@@ -239,15 +243,21 @@ Add a column to the index.
 
 =back
 
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>,
+L<C<Alzabo::Exception::RDBMSRules>|Alzabo::Exceptions>
+
 =head2 delete_column (C<Alzabo::Create::Column> object)
 
-Delete the given column from the index.
+Deletes the given column from the index.
+
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>,
+L<C<Alzabo::Exception::RDBMSRules>|Alzabo::Exceptions>
 
 =for pod_merge prefix
 
 =head2 set_prefix
 
-=head3 Parameters
+This method takes the following parameters:
 
 =over 4
 
@@ -257,11 +267,14 @@ Delete the given column from the index.
 
 =back
 
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>,
+L<C<Alzabo::Exception::RDBMSRules>|Alzabo::Exceptions>
+
 =for pod_merge unique
 
 =head2 set_unique ($boolean)
 
-Set whether or not the index is a unique index.
+Sets whether or not the index is a unique index.
 
 =for pod_merge fulltext
 
@@ -269,9 +282,12 @@ Set whether or not the index is a unique index.
 
 Set whether or not the index is a fulltext index.
 
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>,
+L<C<Alzabo::Exception::RDBMSRules>|Alzabo::Exceptions>
+
 =head2 register_column_name_change
 
-=head3 Parameters
+This method takes the following parameters:
 
 =over 4
 
@@ -283,8 +299,10 @@ The column (with the new name already set).
 
 =back
 
-Called by the owning table object when a column changes.  You should
-never need to call this yourself.
+This method is called by the table object which owns the index when a
+column name changes.  You should never need to call this yourself.
+
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
 
 =for pod_merge id
 
