@@ -7,6 +7,8 @@ use Alzabo::ChangeTracker;
 use Alzabo::Config;
 use Alzabo::Create;
 use Alzabo::Driver;
+use Alzabo::Exceptions
+    ( abbr => [ qw( params_exception system_exception ) ] );
 use Alzabo::RDBMSRules;
 use Alzabo::Runtime;
 use Alzabo::SQLMaker;
@@ -14,7 +16,8 @@ use Alzabo::SQLMaker;
 use File::Spec;
 
 use Params::Validate qw( :all );
-Params::Validate::validation_options( on_fail => sub { Alzabo::Exception::Params->throw( error => join '', @_ ) } );
+Params::Validate::validation_options
+    ( on_fail => sub { params_exception join '', @_ } );
 
 use Storable ();
 use Tie::IxHash;
@@ -36,9 +39,9 @@ sub new
 
     my $self = bless {}, $class;
 
-    Alzabo::Exception::Params->throw( error => "Alzabo does not support the '$p{rdbms}' RDBMS" )
-	unless ( ( grep { $p{rdbms} eq $_ } Alzabo::Driver->available ) &&
-		 ( grep { $p{rdbms} eq $_ } Alzabo::RDBMSRules->available ) );
+    params_exception "Alzabo does not support the '$p{rdbms}' RDBMS"
+        unless ( ( grep { $p{rdbms} eq $_ } Alzabo::Driver->available ) &&
+                 ( grep { $p{rdbms} eq $_ } Alzabo::RDBMSRules->available ) );
 
     $self->{driver} = Alzabo::Driver->new( rdbms => $p{rdbms},
 					   schema => $self );
@@ -46,8 +49,8 @@ sub new
 
     $self->{sql} = Alzabo::SQLMaker->load( rdbms => $p{rdbms} );
 
-    Alzabo::Exception::Params->throw( error => "Alzabo::Create::Schema->new requires a name parameter\n" )
-	unless exists $p{name};
+    params_exception "Alzabo::Create::Schema->new requires a name parameter\n"
+        unless exists $p{name};
 
     $self->set_name($p{name});
 
@@ -101,14 +104,8 @@ sub set_name
     if ($@)
     {
 	$self->{name} = $old_name;
-	if ( UNIVERSAL::can( $@, 'rethrow' ) )
-	{
-	    $@->rethrow;
-	}
-	else
-	{
-	    Alzabo::Exception->throw( error => $@ );
-	}
+
+        rethrow_exception($@);
     }
 
     # Gotta clean up old files or we have a mess!
@@ -153,7 +150,7 @@ sub add_table
 
     my $table = $p{table};
 
-    Alzabo::Exception::Params->throw( error => "Table " . $table->name . " already exists in schema" )
+    params_exception "Table " . $table->name . " already exists in schema"
 	if $self->{tables}->EXISTS( $table->name );
 
     $self->{tables}->STORE( $table->name, $table );
@@ -176,7 +173,7 @@ sub delete_table
     validate_pos( @_, { isa => 'Alzabo::Create::Table' } );
     my $table = shift;
 
-    Alzabo::Exception::Params->throw( error => "Table " . $table->name ." doesn't exist in schema" )
+    params_exception "Table " . $table->name ." doesn't exist in schema"
 	unless $self->{tables}->EXISTS( $table->name );
 
     foreach my $fk ($table->all_foreign_keys)
@@ -203,21 +200,22 @@ sub move_table
 
     if ( exists $p{before} && exists $p{after} )
     {
-	Alzabo::Exception::Params->throw( error => "move_table method cannot be called with both 'before' and 'after' parameters" );
+	params_exception
+            "move_table method cannot be called with both 'before' and 'after' parameters";
     }
 
     if ( $p{before} )
     {
-	Alzabo::Exception::Params->throw( error => "Table " . $p{before}->name . " doesn't exist in schema" )
+	params_exception "Table " . $p{before}->name . " doesn't exist in schema"
 	    unless $self->{tables}->EXISTS( $p{before}->name );
     }
     else
     {
-	Alzabo::Exception::Params->throw( error => "Table " . $p{after}->name . " doesn't exist in schema" )
+	params_exception "Table " . $p{after}->name . " doesn't exist in schema"
 	    unless $self->{tables}->EXISTS( $p{after}->name );
     }
 
-    Alzabo::Exception::Params->throw( error => "Table " . $p{table}->name . " doesn't exist in schema" )
+    params_exception "Table " . $p{table}->name . " doesn't exist in schema"
 	unless $self->{tables}->EXISTS( $p{table}->name );
 
     $self->{tables}->DELETE( $p{table}->name );
@@ -243,7 +241,7 @@ sub register_table_name_change
 		    old_name => { type => SCALAR } } );
     my %p = @_;
 
-    Alzabo::Exception::Params->throw( error => "Table $p{old_name} doesn't exist in schema" )
+    params_exception "Table $p{old_name} doesn't exist in schema"
 	unless $self->{tables}->EXISTS( $p{old_name} );
 
     my $index = $self->{tables}->Indices( $p{old_name} );
@@ -267,29 +265,35 @@ sub add_relationship
 	return;
     }
 
-    Alzabo::Exception::Params->throw( error => "Must provide 'table_from' or 'columns_from' parameter" )
+    params_exception "Must provide 'table_from' or 'columns_from' parameter"
 	unless $p{table_from} || $p{columns_from};
 
-    Alzabo::Exception::Params->throw( error => "Must provide 'table_to' or 'columns_to' parameter" )
+    params_exception "Must provide 'table_to' or 'columns_to' parameter"
 	unless $p{table_to} || $p{columns_to};
 
-    $p{columns_from} = ( defined $p{columns_from} ? ( UNIVERSAL::isa( $p{columns_from}, 'ARRAY') ?
-						      $p{columns_from} :
-						      [ $p{columns_from} ] ) :
-			 undef );
+    $p{columns_from} =
+        ( defined $p{columns_from} ?
+          ( UNIVERSAL::isa( $p{columns_from}, 'ARRAY') ?
+            $p{columns_from} :
+            [ $p{columns_from} ] ) :
+          undef );
 
-    $p{columns_to} = ( defined $p{columns_to} ? ( UNIVERSAL::isa( $p{columns_to}, 'ARRAY') ?
-						  $p{columns_to} :
-						  [ $p{columns_to} ] ) :
-		       undef );
+    $p{columns_to} =
+        ( defined $p{columns_to} ?
+          ( UNIVERSAL::isa( $p{columns_to}, 'ARRAY') ?
+            $p{columns_to} :
+            [ $p{columns_to} ] ) :
+          undef );
 
     my $f_table = $p{table_from} || $p{columns_from}->[0]->table;
     my $t_table = $p{table_to} || $p{columns_to}->[0]->table;
 
     if ( $p{columns_from} && $p{columns_to} )
     {
-	Alzabo::Exception::Params->throw( error => "Cannot create a relationship with differing numbers of columns on either side of the relation" )
-	    unless @{ $p{columns_from} } == @{ $p{columns_to} };
+	params_exception
+            "Cannot create a relationship with differing numbers of columns " .
+            "on either side of the relation"
+                unless @{ $p{columns_from} } == @{ $p{columns_to} };
     }
 
     foreach ( [ columns_from => $f_table ], [ columns_to => $t_table ] )
@@ -297,8 +301,10 @@ sub add_relationship
 	my ($key, $table) = @$_;
 	if ( defined $p{$key} )
 	{
-	    Alzabo::Exception::Params->throw( error => "All the columns in a given side of the relationship must be from the same table" )
-		if grep { $_->table ne $table } @{ $p{$key} };
+	    params_exception
+                "All the columns in a given side of the relationship ".
+                "must be from the same table"
+                    if grep { $_->table ne $table } @{ $p{$key} };
 	}
     }
 
@@ -307,13 +313,18 @@ sub add_relationship
     my ($col_from, $col_to);
 
     # cardinality from -> to
-    my $cardinality = ( $p{cardinality}->[0] eq '1' && $p{cardinality}->[1] eq '1' ? '1_to_1' :
-			( $p{cardinality}->[0] eq '1' && $p{cardinality}->[1] eq 'n' ? '1_to_n' : 'n_to_1' ) );
+    my $cardinality =
+        ( $p{cardinality}->[0] eq '1' && $p{cardinality}->[1] eq '1' ?
+          '1_to_1' :
+          $p{cardinality}->[0] eq '1' && $p{cardinality}->[1] eq 'n' ?
+          '1_to_n' :
+          'n_to_1'
+        );
     my $method = "_create_${cardinality}_relationship";
 
     ($col_from, $col_to) = $self->$method( %p,
-					   table_from   => $f_table,
-					   table_to     => $t_table,
+					   table_from => $f_table,
+					   table_to   => $t_table,
 					 );
 
     eval
@@ -329,14 +340,8 @@ sub add_relationship
     if ($@)
     {
 	$tracker->backout;
-	if ( UNIVERSAL::can( $@, 'rethrow' ) )
-	{
-	    $@->rethrow;
-	}
-	else
-	{
-	    Alzabo::Exception->throw( error => $@ );
-	}
+
+        rethrow_exception($@);
     }
 
     my @fk;
@@ -351,21 +356,20 @@ sub add_relationship
     if ($@)
     {
 	$tracker->backout;
-	if ( UNIVERSAL::can( $@, 'rethrow' ) )
-	{
-	    $@->rethrow;
-	}
-	else
-	{
-	    Alzabo::Exception->throw( error => $@ );
-	}
+
+        rethrow_exception($@);
     }
 
     $tracker->add( sub { $f_table->delete_foreign_key($_) foreach @fk } );
 
     # cardinality to -> to
-    my $inverse_cardinality = ( $p{cardinality}->[1] eq '1' && $p{cardinality}->[0] eq '1' ? '1_to_1' :
-				( $p{cardinality}->[1] eq '1' && $p{cardinality}->[0] eq 'n' ? '1_to_n' : 'n_to_1' ) );
+    my $inverse_cardinality =
+        ( $p{cardinality}->[1] eq '1' && $p{cardinality}->[0] eq '1' ?
+          '1_to_1' :
+          $p{cardinality}->[1] eq '1' && $p{cardinality}->[0] eq 'n' ?
+          '1_to_n' :
+          'n_to_1'
+        );
     my $inverse_method = "_create_${inverse_cardinality}_relationship";
 
     ($col_from, $col_to) = $self->$method( table_from => $t_table,
@@ -400,14 +404,8 @@ sub add_relationship
     if ($@)
     {
 	$tracker->backout;
-	if ( UNIVERSAL::can( $@, 'rethrow' ) )
-	{
-	    $@->rethrow;
-	}
-	else
-	{
-	    Alzabo::Exception->throw( error => $@ );
-	}
+
+        rethrow_exception($@);
     }
 }
 # old name - deprecated
@@ -421,21 +419,21 @@ sub _check_add_relationship_args
     foreach my $t ( $p{table_from}, $p{table_to} )
     {
 	next unless defined $t;
-	Alzabo::Exception::Params->throw( error => "Table " . $t->name . " doesn't exist in schema" )
+	params_exception "Table " . $t->name . " doesn't exist in schema"
 	    unless $self->{tables}->EXISTS( $t->name );
     }
 
-    Alzabo::Exception::Params->throw( error => "Incorrect number of cardinality elements" )
+    params_exception "Incorrect number of cardinality elements"
 	unless scalar @{ $p{cardinality} } == 2;
 
     foreach my $c ( @{ $p{cardinality} } )
     {
-	Alzabo::Exception::Params->throw( error => "Invalid cardinality: $c" )
-		unless $c =~ /^[01n]$/i;
+	params_exception "Invalid cardinality: $c"
+            unless $c =~ /^[01n]$/i;
     }
 
     # No such thing as 1..0 or n..0
-    Alzabo::Exception::Params->throw( error => "Invalid cardinality: $p{cardinality}->[0]..$p{cardinality}->[1]" )
+    params_exception "Invalid cardinality: $p{cardinality}->[0]..$p{cardinality}->[1]"
 	if  $p{cardinality}->[1] eq '0';
 }
 
@@ -483,7 +481,7 @@ sub _create_1_to_1_relationship
     {
 	my @c = $t_table->primary_key;
 
-	Alzabo::Exception::Params->throw( error => $t_table->name . " has no primary key." )
+	params_exception $t_table->name . " has no primary key."
 	    unless @c;
 
 	$col_to = \@c;
@@ -531,7 +529,7 @@ sub _create_1_to_n_relationship
 	my @c = $f_table->primary_key;
 
 	# Is there a way to handle this properly?
-	Alzabo::Exception::Params->throw( error => $f_table->name . " has no primary key." )
+	params_exception $f_table->name . " has no primary key."
 	    unless @c;
 
 	$col_from = \@c;
@@ -568,7 +566,8 @@ sub _create_n_to_1_relationship
     # reverse everything ...
     ($p{table_from}, $p{table_to}) = ($p{table_to}, $p{table_from});
     ($p{columns_from}, $p{columns_to}) = ($p{columns_to}, $p{columns_from});
-    ($p{from_is_dependent}, $p{to_is_dependent}) = ($p{to_is_dependent}, $p{from_is_dependent});
+    ($p{from_is_dependent}, $p{to_is_dependent}) =
+        ($p{to_is_dependent}, $p{from_is_dependent});
 
     # pass it into the inverse method and then swap the return values.
     # Tada!
@@ -604,9 +603,11 @@ sub _add_foreign_key_column
 	# This will make the two column share a single definition
 	# object.
 	my $old_def = $p{table}->column( $p{column}->name )->definition;
-	$p{table}->column( $p{column}->name )->change_definition($p{column}->definition);
+	$p{table}->column( $p{column}->name )->set_definition($p{column}->definition);
 
-	$tracker->add( sub { $p{table}->column( $p{column}->name )->change_definition($old_def) } );
+	$tracker->add
+            ( sub { $p{table}->column
+                        ( $p{column}->name )->set_definition($old_def) } );
     }
     else
     {
@@ -642,7 +643,7 @@ sub _create_linking_table
     {
 	my @c = $t1->primary_key;
 
-	Alzabo::Exception::Params->throw( error => $t1->name . " has no primary key." )
+	params_exception $t1->name . " has no primary key."
 	    unless @c;
 
 	$t1_col = \@c;
@@ -657,7 +658,7 @@ sub _create_linking_table
     {
 	my @c = $t2->primary_key;
 
-	Alzabo::Exception::Params->throw( error => $t2->name . " has no primary key." )
+	params_exception $t2->name . " has no primary key."
 	    unless @c;
 
 	$t2_col = \@c;
@@ -719,14 +720,8 @@ sub _create_linking_table
     if ($@)
     {
 	$tracker->backout;
-	if ( UNIVERSAL::can( $@, 'rethrow' ) )
-	{
-	    $@->rethrow;
-	}
-	else
-	{
-	    Alzabo::Exception->throw( error => $@ );
-	}
+
+        rethrow_exception($@);
     }
 }
 
@@ -840,18 +835,34 @@ sub delete
 
     my $dh = do { local *DH; };
     opendir $dh, $schema_dir
-	or Alzabo::Exception::System->throw( error => "Unable to open $schema_dir directory: $!" );
+	or system_exception "Unable to open $schema_dir directory: $!";
+
     foreach my $f (readdir $dh)
     {
 	my $file = File::Spec->catfile( $schema_dir, $f );
 	next unless -f $file;
 
 	unlink $file
-	    or Alzabo::Exception::System->throw( error => "Unable to delete $file: $!" );
+	    or system_exception "Unable to delete $file: $!";
     }
-    closedir $dh or Alzabo::Exception::System->throw( error => "Unable to close $schema_dir: $!" );
+    closedir $dh
+        or system_exception "Unable to close $schema_dir: $!";
+
     rmdir $schema_dir
-	or Alzabo::Exception::System->throw( error => "Unable to delete $schema_dir: $!" );
+	or system_exception "Unable to delete $schema_dir: $!";
+}
+
+sub is_saved
+{
+    my $self = shift;
+
+    my %p = @_;
+
+    my $name = $p{name} || $self->name;
+
+    my $schema_dir = File::Spec->catdir( Alzabo::Config::schema_dir(), $name );
+
+    return -d $schema_dir;
 }
 
 sub save_to_file
@@ -862,49 +873,52 @@ sub save_to_file
     unless (-e $schema_dir)
     {
 	mkdir $schema_dir, 0775
-	    or Alzabo::Exception::System->throw( error => "Unable to make directory $schema_dir: $!" );
+	    or system_exception "Unable to make directory $schema_dir: $!";
     }
 
     my $create_save_name = $self->_base_filename( $self->{name} ) . '.create.alz';
 
     my $fh = do { local *FH; };
     open $fh, ">$create_save_name"
-	or Alzabo::Exception::System->throw( error => "Unable to write to $create_save_name: $!\n" );
+	or system_exception "Unable to write to $create_save_name: $!\n";
+
     my $driver = delete $self->{driver};
     Storable::nstore_fd( $self, $fh )
-	or Alzabo::Exception::System->throw( error => "Can't store to filehandle" );
+	or system_exception "Can't store to filehandle";
+
     $self->{driver} = $driver;
     close $fh
-	or Alzabo::Exception::System->throw( error => "Unable to close $create_save_name: $!" );
+	or system_exception "Unable to close $create_save_name: $!";
 
     my $rdbms_save_name = $self->_base_filename( $self->{name} ) . '.rdbms';
 
     open $fh, ">$rdbms_save_name"
-	or Alzabo::Exception::System->throw( error => "Unable to write to $rdbms_save_name: $!\n" );
+	or system_exception "Unable to write to $rdbms_save_name: $!\n";
+
     print $fh $self->{driver}->driver_id
-	or Alzabo::Exception::System->throw( error => "Can't write to $rdbms_save_name: $!" );
+	or system_exception "Can't write to $rdbms_save_name: $!";
     close $fh
-	or Alzabo::Exception::System->throw( error => "Unable to close $rdbms_save_name: $!" );
+	or system_exception "Unable to close $rdbms_save_name: $!";
 
     my $version_save_name = $self->_base_filename( $self->{name} ) . '.version';
 
     open $fh, ">$version_save_name"
-	or Alzabo::Exception::System->throw( error => "Unable to write to $version_save_name: $!\n" );
+	or system_exception "Unable to write to $version_save_name: $!\n";
     print $fh $Alzabo::VERSION
-	or Alzabo::Exception::System->throw( error => "Can't write to $version_save_name: $!" );
+	or system_exception "Can't write to $version_save_name: $!";
     close $fh
-	or Alzabo::Exception::System->throw( error => "Unable to close $version_save_name: $!" );
+	or system_exception "Unable to close $version_save_name: $!";
 
     my $rt = $self->_make_runtime_clone;
 
     my $runtime_save_name = $self->_base_filename( $self->{name} ) . '.runtime.alz';
 
     open $fh, ">$runtime_save_name"
-	or Alzabo::Exception::System->throw( error => "Unable to write to $runtime_save_name: $!\n" );
+	or system_exception "Unable to write to $runtime_save_name: $!\n";
     Storable::nstore_fd( $rt, $fh )
-	or Alzabo::Exception::System->throw( error => "Can't store to filehandle" );
+	or system_exception "Can't store to filehandle";
     close $fh
-	or Alzabo::Exception::System->throw( error => "Unable to close $runtime_save_name: $!" );
+	or system_exception "Unable to close $runtime_save_name: $!";
 
     $self->_save_to_cache;
 }
@@ -1014,6 +1028,37 @@ which in turn contain columns, indexes, etc.  It contains methods that
 act globally on the schema, including methods to save it to disk,
 create itself in an RDBMS, create relationships between tables, etc.
 
+=head2 Instantiation
+
+Every schema keeps track of whether it has been instantiated or not.
+A schema that is instantiated is one that exists in an RDBMS backend.
+This can be done explicitly by calling the schema's
+L<C<create()>|Alzabo::Create::Schema/create> method.  It is also
+implicitly set when a schema is created as the result of L<reverse
+engineering|Alzabo::Create::Schema/reverse_engineer>.
+
+The most important effect of instantiation is that once a schema is
+instantiated, the way it generates SQL for itself changes.  Before it
+is instantiated, if you ask it to generate SQL via L<the C<make_sql()>
+the method|Alzabo::Create::Schema/make_sql>, it will generate the set
+of SQL statements that are needed to create the schema from scratch.
+
+After it is instantiated, the schema will instead generate the SQL
+necessary to convert the version in the RDBMS backend to match the
+object's current state.  This can be thought of as a SQL 'diff'.
+
+While this feature is quite useful, it can be confusing too.  The most
+surprising aspect of this is that if you create a schema via L<reverse
+engineering|Alzabo::Create::Schema/reverse_engineer> and then call
+L<the C<make_sql()> method|Alzabo::Create::Schema/make_sql>, you will
+not get any SQL.  This is because the schema knows that it is
+instantiated and it also knows that it is the same as the version in
+the RDBMS, so no SQL is necessary.
+
+You can use L<the C<set_instantiated()>
+method|Alzabo::Create::Schema/set_instantiated ($bool)> method to
+change whether or not the schem thinks it is instantiated.
+
 =head1 INHERITS FROM
 
 C<Alzabo::Schema>
@@ -1026,7 +1071,7 @@ C<Alzabo::Schema>
 
 =head2 new
 
-=head3 Parameters
+This constructor takes the following parameters:
 
 =over 4
 
@@ -1044,18 +1089,14 @@ method.  These are values such as 'MySQL', 'PostgreSQL', etc.
 
 =back
 
-=head3 Returns
+It returns a new C<Alzabo::Create::Schema> object.
 
-A new C<Alzabo::Create::Schema> object.
-
-=head3 Throws
-
-L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>,
 L<C<Alzabo::Exception::System>|Alzabo::Exceptions>
 
 =head2 load_from_file
 
-=head3 Parameters
+This constructor takes the following parameters:
 
 =over 4
 
@@ -1063,15 +1104,11 @@ L<C<Alzabo::Exception::System>|Alzabo::Exceptions>
 
 =back
 
-Returns a schema object previously saved to disk.
+Returns a schema object previously saved to disk, as specified by the
+"name" parameters.
 
-=head3 Returns
-
-The C<Alzabo::Create::Schema> object specified by the name parameter.
-
-=head3 Throws
-
-L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>,
+L<C<Alzabo::Exception::System>|Alzabo::Exceptions>
 
 =head2 reverse_engineer
 
@@ -1082,13 +1119,9 @@ changes will lead to SQL diffs, as opposed to SQL to create the
 database from scratch.
 
 The schema object returned by this method will have its instantiated
-attribute set as true.  This means that calling the C<make_sql> method
-on the object won't generate any SQL.  To do this you'd have to first
-call
-L<C<$schema-E<gt>set_instantiated(0)>|Alzabo::Create::Schema/set_instantiated
-($bool)> and then L<C<$schema-E<gt>make_sql>|make_sql>.
+attribute set as true.
 
-=head3 Parameters
+It takes the following parameters:
 
 =over 4
 
@@ -1104,12 +1137,10 @@ parameter.
 =back
 
 In addition, this method takes any parameters that can be used when
-connecting to the RDBMS, including C<user>, C<password>, C<host>, and
-C<port>.
+connecting to the RDBMS, including "user", "password", "host", and
+"port".
 
-=head3 Returns
-
-A new C<Alzabo::Create::Schema> object.
+Returns a new C<Alzabo::Create::Schema> object.
 
 =head2 Other Methods
 
@@ -1117,10 +1148,14 @@ A new C<Alzabo::Create::Schema> object.
 
 =head2 set_name ($name)
 
-Change the schema name.  Since schemas are saved on disk with
+Changes the schema name.  Since schemas are saved on disk with
 filenames based on the schema name, this deletes the files for the old
-name.  Call L<C<save_to_file>|save_to_file> immediately afterwards if
-you want to make sure you have a copy of the schema saved.
+name.  Call L<C<save_to_file()>|save_to_file> immediately afterwards
+if you want to make sure you have a copy of the schema saved.
+
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>,
+L<C<Alzabo::Exception::RDBMSRules>|Alzabo::Exceptions>,
+L<C<Alzabo::Exception::System>|Alzabo::Exceptions>
 
 =for pod_merge table
 
@@ -1131,30 +1166,32 @@ you want to make sure you have a copy of the schema saved.
 =head2 make_table
 
 This method makes a new table and adds it to the schema, the
-parameters given are passed directly to the
-L<C<Alzabo::Create::Table-E<gt>new>|Alzabo::Create::Table/new> method.
-The schema parameter is filled in automatically.
+parameters given are passed directly to the L<C<<
+Alzabo::Create::Table->new() >>|Alzabo::Create::Table/new> method.
+The "schema" parameter is filled in automatically.
 
-=head3 Returns
+If a "before" or "after" parameter is given then the
+L<C<move_table()>|move_table> method will be called to move the new
+table to the appropriate position.
 
-The L<C<Alzabo::Create::Table>|Alzabo::Create::Table> object created.
+Returns a new L<C<Alzabo::Create::Table>|Alzabo::Create::Table>
+object.
+
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>,
+L<C<Alzabo::Exception::RDBMSRules>|Alzabo::Exceptions>
 
 =head2 delete_table (C<Alzabo::Create::Table> object)
 
 Removes the given table from the schema.  This method will also delete
 all foreign keys in other tables that point at the given table.
 
-=head3 Throws
-
-L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
 
 =head2 add_table
 
-Add a table to the schema.  If a before or after parameter is given
-then the L<C<move_table>|move_table> method will be called to move the
-new table to the appropriate position.
+Add a table to the schema.
 
-=head3 Parameters
+This methods takes the following parameters:
 
 =over 4
 
@@ -1168,20 +1205,17 @@ new table to the appropriate position.
 
 =back
 
-=head3 Returns
+Returns a new L<C<Alzabo::Create::Table>|Alzabo::Create::Table>
+object.
 
-The L<C<Alzabo::Create::Table>|Alzabo::Create::Table> object created.
-
-=head3 Throws
-
-L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
 
 =head2 move_table
 
 Allows you to change the order of the tables as they are stored in the
 schema.
 
-=head3 Parameters
+This method takes the following parameters:
 
 =over 4
 
@@ -1203,28 +1237,25 @@ Move the table after this table.
 
 =back
 
-=head3 Throws
-
-L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
 
 =head2 add_relationship
 
 Creates a relationship between two tables.  This involves creating
 L<C<Alzabo::Create::ForeignKey>|Alzabo::Create::ForeignKey> objects in
-both tables.  If the C<columns_from> and C<columns_to> parameters are
+both tables.  If the "columns_from" and "columns_to" parameters are
 not specified then the schema object attempts to calculate the proper
 values for these attributes.
 
 To do this, Alzabo attempts to determine the dependencies of the
 tables.  If you have specified a cardinality of 1..1, or n..1, in
 cases where both tables are independent, or where they are both
-dependent (which makes little sense, but it's your code, so...) then
-the C<table_from> is treated as being the dependent table for the
-purposes of determining
+dependent then the "table_from" is treated as being the dependent
+table for the purposes of determining
 
 If no columns with the same names exist in the other table, then
-columns with those names will be created.  Otherwise, add_relationship
-changes the dependent columns so that their
+columns with those names will be created.  Otherwise,
+C<add_relationship()> changes the dependent columns so that their
 L<C<Alzabo::Create::ColumnDefinition>|Alzabo::Create::ColumnDefinition>
 objects are the same as the columns in the table upon which they are
 dependent, meaning that changes to the type of one column affects both
@@ -1232,11 +1263,11 @@ at the same time.
 
 If you want to make a multi-column relationship, the assumption is
 that the order of the columns is significant.  In other words, the
-first column in the C<columns_from> parameter is assumed to correspond
-to the first column in hte C<columns_to> parameter and so on.
+first column in the "columns_from" parameter should correspond to the
+first column in hte "columns_to" parameter and so on.
 
-The number of columns given in C<columns_from> and C<columns_to> must
-be the same except when creating a many to many relationship.
+The number of columns given in "columns_from" and "columns_to" must be
+the same except when creating a many to many relationship.
 
 If the cardinality is many to many then a new table will be created to
 link the two tables together.  This table will contain the primary
@@ -1244,7 +1275,7 @@ keys of both the tables passed into this function.  It will contain
 foreign keys to both of these tables as well, and these tables will be
 linked to this new table.
 
-=head3 Parameters
+This method takes the following parameters:
 
 =over 4
 
@@ -1273,9 +1304,7 @@ names of those it's linking.
 
 =back
 
-=head3 Throws
-
-L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
 
 =head2 create
 
@@ -1289,41 +1318,37 @@ schema to be marked as instantiated.
 
 Wherever possible, existing data will be preserved.
 
-=head3 Parameters
-
 This method takes any parameters that can be used when connecting to
-the RDBMS, including C<user>, C<password>, C<host>, and C<port>.
+the RDBMS, including "user", "password", "host", and "port".
 
 =head2 instantiated
 
-=head3 Returns
-
-The value of the schema's instantiated attribute.  It is true if the
-schema has been created in an RDBMS backend, otherwise it is false.
+Returns a boolean value indicating whether the schema has been created
+in an RDBMS backend, otherwise it is false.
 
 =head2 set_instantiated ($bool)
 
 Set the schema's instantiated attribute as true or false.
 
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
+
 =head2 make_sql
 
-=head3 Returns
-
-An array containing the SQL statements necessary to either create the
-database from scratch or update the database to match the schema
-object.  See the L<C<create>|Alzabo::Create::Schema/create> method for
-more details.
+Returns an array containing the SQL statements necessary to either
+create the database from scratch or update the database to match the
+schema object.  See the L<C<create()>|Alzabo::Create::Schema/create>
+method for more details.
 
 =head2 drop
 
 Drops the database/schema from the RDBMS.  This will cause the schema
 to be marked as not instantiated.  This method does not delete the
-Alzabo files from disk.  To do this, call the C<delete> method.
-
-=head3 Parameters
+Alzabo files from disk.  To do this, call the C<delete()> method.
 
 This method takes any parameters that can be used when connecting to
-the RDBMS, including C<user>, C<password>, C<host>, and C<port>.
+the RDBMS, including "user", "password", "host", and "port".
+
+Throws: L<C<Alzabo::Exception::Driver>|Alzabo::Exceptions>
 
 =head2 sync_backend
 
@@ -1331,7 +1356,7 @@ This method will look at the schema as it exists in the RDBMS backend,
 and make any changes that are necessary in order to make this backend
 schema match the Alzabo schema object.  If there is no corresponding
 schema in the RDBMS backend, then this method is equivalent to the
-L<C<create>|Alzabo::Create::Schema/create> method.
+L<C<create()>|Alzabo::Create::Schema/create> method.
 
 After this method is called, the schema will be considered to be
 instantiated.
@@ -1344,35 +1369,32 @@ account for these.
 In the end, this means that Alzabo may never think that a schema in
 the RDBMS exactly matches the state of the Alzabo schema object.  Even
 immediately after running this method, running it again may still
-cause it to execute SQL commands.  Fortunately, the SQL it generates
+2cause it to execute SQL commands.  Fortunately, the SQL it generates
 will not cause anything to break.
 
-=head3 Parameters
-
 This method takes any parameters that can be used when connecting to
-the RDBMS, including C<user>, C<password>, C<host>, and C<port>.
+the RDBMS, including "user", "password", "host", and "port".
+
+Throws: L<C<Alzabo::Exception::Driver>|Alzabo::Exceptions>
 
 =head2 sync_backend_sql
 
-=head3 Parameters
-
-This method takes any parameters that can be used when connecting to
-the RDBMS, including C<user>, C<password>, C<host>, and C<port>.
-
-=head3 Returns
-
-This method returns an array containing the set of SQL statements that
-would be used by the L<C<sync_backend_sql>|sync_backend_sql> method.
-
 If there is no corresponding schema in the RDBMS backend, then this
 method returns the SQL necessary to create the schema from scratch.
 
+This method takes any parameters that can be used when connecting to
+the RDBMS, including "user", "password", "host", and "port".
+
+Throws: L<C<Alzabo::Exception::Driver>|Alzabo::Exceptions>
+
 =head2 delete
 
 Removes the schema object from disk.  It does not delete the database
 from the RDBMS.  To do this you must call the L<C<drop>|drop> method
 first.
 
+Throws: L<C<Alzabo::Exception::System>|Alzabo::Exceptions>
+
 =head2 clone
 
 This method creates a new object identical to the one that the method
@@ -1380,7 +1402,7 @@ was called on, except that this new schema has a different name, it
 does not yet exist on disk, its instantiation attribute is set to
 false.
 
-=head3 Parameters
+It takes the following parameters:
 
 =over 4
 
@@ -1388,14 +1410,21 @@ false.
 
 =back
 
-=head3 Returns
+This method returns a new Alzabo::Create::Schema object.
 
-A new Alzabo::Create::Schema object.
+Throws: L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>,
+L<C<Alzabo::Exception::RDBMSRules>|Alzabo::Exceptions>
 
 =head2 save_to_file
 
 Saves the schema to a file on disk.
 
+Throws: L<C<Alzabo::Exception::System>|Alzabo::Exceptions>
+
+=head2 is_saved
+
+Returns true if the schema has been saved to disk.
+
 =for pod_merge begin_work
 
 =for pod_merge rollback
