@@ -42,17 +42,6 @@ sub _insert_or_update
 	# to insert things into the table.
 	next if $type eq 'insert' && $pair->[0]->is_primary_key;
 
-	# This code may be unreachable because this may always be
-	# caught in Alzabo::Runtime::Table::insert or
-	# Alzabo::Runtime::Row::update where it won't let you use null
-	# for a non-nullable column.  And in
-	# Alzabo::Create::Schema::add_relation we make sure that
-	# dependent columns are not nullable.
-	if ( ! defined $vals{ $pair->[0]->name } && $self->from_is_dependent )
-	{
-	    Alzabo::Exception::ReferentialIntegrity->throw( error => 'Referential integrity requires that this column (' . $self->table_from->name . '.' . $pair->[0]->name . ') not be null.' )
-	}
-
 	if ( $type eq 'update' || $pair->[1]->is_primary_key )
 	{
 	    $self->_check_existence( $pair->[1] => $vals{ $pair->[0]->name } )
@@ -103,8 +92,6 @@ sub register_delete
 
     while ( my $related_row = $cursor->next )
     {
-	($cursor->errors)[0]->rethrow if $cursor->errors;
-
 	# This is a class variable so that multiple foreign key
 	# objects don't try to delete the same rows
 	next if $DELETED{ $related_row->id_as_string };
@@ -140,9 +127,8 @@ Alzabo::Runtime::ForeignKey - Foreign key objects
 =head1 DESCRIPTION
 
 Objects in this class maintain referential integrity.  This is really
-only useful when your RDBMS can't do this itself (like MySQL).  For a
-RDBMS that can do this, this feature can be turned off
-(by doing C<$schema-E<gt>set_referential_integrity(0)>).
+only useful when your RDBMS can't do this itself (like MySQL without
+InnoDB).
 
 =head1 INHERITS FROM
 
@@ -172,24 +158,22 @@ C<Alzabo::ForeignKey>
 
 =for pod_merge is_many_to_one
 
+=for pod_merge is_same_relationship_as ($fk)
+
 =head2 register_insert ($new_value)
 
 This method takes the proposed column value for a new row and makes
 sure that it is valid based on relationship that this object
 represents.
 
-=head3 Throws
-
-L<C<Alzabo::Exception::ReferentialIntegrity>|Alzabo::Exceptions>
+Throws: L<C<Alzabo::Exception::ReferentialIntegrity>|Alzabo::Exceptions>
 
 =head2 register_update ($new_value)
 
 This method takes the proposed new value for a column and makes sure
 that it is valid based on relationship that this object represents.
 
-=head3 Throws
-
-L<C<Alzabo::Exception::ReferentialIntegrity>|Alzabo::Exceptions>
+Throws: L<C<Alzabo::Exception::ReferentialIntegrity>|Alzabo::Exceptions>
 
 =head2 register_delete (C<Alzabo::Runtime::Row> object)
 
@@ -197,9 +181,11 @@ Allows the foreign key to delete rows dependent on the row being
 deleted.  Note, this can lead to a chain reaction of cascading
 deletions.  You have been warned.
 
-=head3 Throws
+Throws: L<C<Alzabo::Exception::ReferentialIntegrity>|Alzabo::Exceptions>
 
-L<C<Alzabo::Exception::ReferentialIntegrity>|Alzabo::Exceptions>
+=for pod_merge id
+
+=for pod_merge comment
 
 =head1 AUTHOR
 
