@@ -43,7 +43,7 @@ C<delete()> method has been called.
 
 =head1 METHODS
 
-See C<L<Alzabo::Runtime::Row>|Alzabo::Runtime::Row>.
+See L<C<Alzabo::Runtime::Row>|Alzabo::Runtime::Row>.
 
 =head1 AUTHOR
 
