@@ -6,6 +6,7 @@ use vars qw($VERSION %CACHE);
 use Alzabo;
 use Alzabo::Config;
 use Alzabo::Driver;
+use Alzabo::Exceptions ( abbr => 'params_exception' );
 use Alzabo::RDBMSRules;
 use Alzabo::SQLMaker;
 
@@ -76,6 +77,10 @@ sub _load_from_file
 
     ($rdbms) = $rdbms =~ /(\w+)/;
 
+    # This is important because if the user is using MethodMaker, they
+    # might be calling this as My::Schema->load_from_file ...
+    bless $schema, $class;
+
     $schema->{driver} = Alzabo::Driver->new( rdbms => $rdbms,
 					     schema => $schema );
 
@@ -95,7 +100,7 @@ sub _cached_schema
     validate_pos( @_, { type => SCALAR } );
     my $name = shift;
 
-    my $schema_dir = Alzabo::Config::schema_dir;
+    my $schema_dir = Alzabo::Config::schema_dir();
     my $file = $class->_schema_filename($name);
 
     if (exists $CACHE{$name}{$class}{object})
@@ -154,38 +159,17 @@ sub table
     my $self = shift;
     my $name = shift;
 
-    if ( my $table = $self->{tables}->FETCH($name) )
-    {
-        return $table;
-    }
-    else
-    {
-        Alzabo::Exception::Params->throw
-            ( error => "Table $name doesn't exist in $self->{name}" );
-    }
+    return
+        $self->{tables}->FETCH($name) ||
+            params_exception "Table $name doesn't exist in $self->{name}";
 }
 
 sub tables
 {
     my $self = shift;
 
-    if (@_)
-    {
-        my @idx = $self->{tables}->Indices(@_);
-
-        # if only some of the keys are in the Tie::IxHash object, then
-        # @idx may contain undef for some values.
-        if ( ( grep { defined } @idx ) == @_ )
-        {
-            return $self->{tables}->Values(@idx);
-        }
-        else
-        {
-            # just to find the missing one(s)
-            $self->table($_) foreach @_;
-        }
-    }
-
+    return $self->table(@_) if @_ == 1;
+    return map { $self->table($_) } @_  if @_ > 1;
     return $self->{tables}->Values;
 }
 
@@ -272,58 +256,43 @@ Alzabo::Schema - Schema objects
 
 =head1 SYNOPSIS
 
-  use Alzabo::Schema;
-
-  my $schema = Alzabo::Schema->load_from_file( name => 'foo' );
-
-  foreach my $t ($schema->tables)
-  {
-     print $t->name;
-  }
+  use base qw(Alzabo::Schema);
 
 =head1 DESCRIPTION
 
-Objects in this class represent the entire schema, containing table
-objects, which in turn contain foreign key objects and column objects,
-which in turn contain column definition objects.
+This is the base class for schema objects..
 
 =head1 METHODS
 
 =head2 name
 
-=head3 Returns
-
-A string containing the name of the schema.
+Returns a string containing the name of the schema.
 
 =head2 table ($name)
 
-=head3 Returns
+Returns an L<C<Alzabo::Table>|Alzabo::Table> object representing the
+specified table.
 
-An L<C<Alzabo::Table>|Alzabo::Table> object representing the specified
-table.
-
-=head3 Throws
-
-L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
+An L<C<Alzabo::Exception::Params>|Alzabo::Exceptions> exception is
+throws if the schema does not contain the table.
 
 =head2 tables (@optional_list)
 
-=head3 Returns
+If no arguments are given, this method returns a list of all
+L<C<Alzabo::Table>|Alzabo::Table> objects in the schema, or in a
+scalar context the number of such tables.  If one or more arguments
+are given, returns a list of table objects with those names, in the
+same order given (or the number of such tables in a scalar context,
+but this isn't terribly useful).
 
-A list of L<C<Alzabo::Table>|Alzabo::Table> object named in the list
-given.  If no list is provided, then it returns all table objects in
-the schema.
-
-=head3 Throws
-
-L<C<Alzabo::Exception::Params>|Alzabo::Exceptions>
+An L<C<Alzabo::Exception::Params>|Alzabo::Exceptions> exception is
+throws if the schema does not contain one or more of the specified
+tables.
 
 =head2 has_table ($name)
 
-=head3 Returns
-
-A true or false value depending on whether or not the table exists in
-the schema.
+Returns a boolean value indicating whether the table exists in the
+schema.
 
 =head2 begin_work
 
@@ -337,7 +306,8 @@ Rollback a transaction.
 =head2 commit
 
 Finishes a transaction with a commit.  If you make multiple calls to
-C<begin_work>, make sure to call this method the same number of times.
+C<begin_work()>, make sure to call this method the same number of
+times.
 
 =head2 run_in_transaction ( sub { code... } )
 
@@ -348,23 +318,16 @@ wrapped code would have returned.
 
 =head2 driver
 
-=head3 Returns
-
-The L<C<Alzabo::Driver>|Alzabo::Driver> subclass object for the
-schema.
+Returns the L<C<Alzabo::Driver>|Alzabo::Driver> object for the schema.
 
 =head2 rules
 
-=head3 Returns
-
-The L<C<Alzabo::RDBMSRules>|Alzabo::RDBMSRules> subclass object for
-the schema.
+Returns the L<C<Alzabo::RDBMSRules>|Alzabo::RDBMSRules> object for the
+schema.
 
 =head2 sqlmaker
 
-=head3 Returns
-
-The L<C<Alzabo::SQLMaker>|Alzabo::SQLMaker> subclass object for the
+Returns the L<C<Alzabo::SQLMaker>|Alzabo::SQLMaker> object for the
 schema.
 
 =head1 AUTHOR
